package Gherkin::Parser;
$Gherkin::Parser::VERSION = '18.0.0';
use strict;
use warnings;

use base 'Gherkin::Generated::Parser';

1;
